@@ -6,8 +6,9 @@ Task for Scheduler and AsyncScheduler
 
 from __future__ import annotations
 
-from typing import Any, Callable
+from typing import Any
 from dataclasses import dataclass, field
+from collections.abc import Callable
 
 
 @dataclass(order=True)
